OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seleccione un archivo, por favor.",
    "File is too big" : "El archivo es demasiado grande",
    "Invalid file provided" : "Archivo no válido",
    "No image or file provided" : "No se especificó ningún archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "An error occurred. Please contact your admin." : "Un error ocurrió. Póngase en contacto con su administrador.",
    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
    "No crop data provided" : "No se proporcionó datos del recorte",
    "No valid crop data provided" : "Recorte inválido",
    "Crop is not square" : "El recorte no es cuadrado",
    "Couldn't reset password because the token is invalid" : "No se puede restablecer la contraseña porque el vale de identificación es inválido.",
    "Couldn't reset password because the token is expired" : "No se puede restablecer la contraseña porque el vale de identificación ha caducado.",
    "%s password changed successfully" : "Contraseña %s cambiada con exito",
    "%s password reset" : "%s restablecer contraseña",
    "Couldn't send reset email. Please contact your administrator." : "No pudo enviarse el correo para restablecer la contraseña. Por favor, contacte con su administrador.",
    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
    "Preparing update" : "Preparando la actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Advertencia de reparación:",
    "Repair error: " : "Error que reparar:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor utilice la actualización mediante la linea de comandos porque la actualización automática está desactivada en config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Comprobando cuadro %s",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Maintenance mode is kept active" : "El modo mantenimiento aún está activo.",
    "Updating database schema" : "Actualizando el esquema del base de datos",
    "Updated database" : "Base de datos actualizada",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
    "Checked database schema update" : "Actualización del esquema de base de datos revisado",
    "Checking updates of apps" : "Comprobar actualizaciones de apps",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos %s (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
    "Checked database schema update for apps" : "Comprobada la actualización del esquema de la base de datos para aplicaciones",
    "Updated \"%s\" to %s" : "Se ha actualizado \"%s\" a %s",
    "Set log level to debug" : "Establecer el nivel de registro a depuración",
    "Reset log level" : "Restablecer el nivel de registro",
    "Starting code integrity check" : "Comenzando comprobación de integridad de código",
    "Finished code integrity check" : "Terminando comprobación de integridad de código",
    "%s (3rdparty)" : "%s (tercer parte)",
    "%s (incompatible)" : "%s (incompatible)",
    "Following apps have been disabled: %s" : "Siguiendo aplicaciones ha sido deshabilitado: %s",
    "Already up to date" : "Ya actualizado",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Ju",
    "Fr" : "Vi",
    "Sa" : "Sa",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Ha habido problemas durante la comprobación de la integridad del código. Más información…</a>",
    "Settings" : "Ajustes",
    "Problem loading page, reloading in 5 seconds" : "Problema al cargar la página, recargando en 5 segundos",
    "Saving..." : "Guardando...",
    "Dismiss" : "Descartar",
    "seconds ago" : "hace segundos",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Se ha enviado un enlace para restablecer su contraseña a su correo electrónico. Si usted no lo recibe en un tiempo razonable, revise su carpeta de spam/chatarra/basura.<br>Si no lo encuentra, consulte a su administrador local.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sus archivos están cifrados. Si no ha activado la clave de recuperación, no habrá manera de recuperar los datos una vez su contraseña sea restablecida.<br /> Si no está seguro de lo que debe hacer, por favor contacte con su administrador antes de continuar.<br />¿Realmente desea continuar?",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Password can not be changed. Please contact your administrator." : "La contraseña no se puede cambiar. Por favor, contacte a su administrador.",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Seleccionar",
    "Error loading file picker template: {error}" : "Error al cargar plantilla del seleccionador de archivos: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error al cargar plantilla del mensaje: {error}",
    "read-only" : "solo lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo"],
    "One file conflict" : "Un conflicto de archivo",
    "New Files" : "Nuevos archivos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Cuáles archivos desea mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(seleccionados todos)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando plantilla de archivo existente",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña buena",
    "Strong password" : "Contraseña muy buena",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Su servidor web aún no está configurado adecuadamente para permitir sincronización de archivos ya que la interfaz WebDAV parece no estar funcionando.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Su servidor no ha sido correctamente configurado para resolver \"{url}\". Puede encontrar más información en nuestra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentación</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor no tiene una conexión a Internet. Esto significa que algunas de las características como el montaje de almacenamiento externo, las notificaciones sobre actualizaciones o instalación de aplicaciones de terceros no funcionan. Podría no funcionar el acceso a los archivos de forma remota y el envío de correos electrónicos de notificación. Sugerimos habilitar la conexión a Internet de este servidor, si quiere tener todas las funciones.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La memoria caché no ha sido configurada. Para mejorar su desempeño, por favor, configure la memcache si está disponible. Puede encontrar más información en nuestra  <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "PHP no tiene acceso a /dev/urandom lo cual es desaconsejable por razones de seguridad. Puede encontrar más información en nuestra our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Actualmente utiliza PHP {version}. Le aconsejamos que actualice su versión de PHP para beneficiarse de <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">mejoras de desempeño y seguridad que aporta PHP Group</a> en cuanto su distribución lo soporte.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La configuración de las cabeceras inversas del proxy son incorrectas, o está accediendo a ownCloud desde un proxy confiable. Si no está accediendo a ownCloud desde un proxy certificado y confiable, este es un problema de seguridad y puede permitirle a un hacker camuflar su dirección IP a ownCloud. Más información puede ser encontrada en nuestra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentación</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "memcached es un sistema de cache distribuido. pero ha sido instalado por error el modulo PHP memcache.\nConsulte  <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki acerca de ambos modulos</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Algunos archivos no han superado la comprobación de integridad. Para más información sobre cómo resolver este inconveniente consulte nuestra documentación <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)",
    "Error occurred while checking server setup" : "Ha ocurrido un error al revisar la configuración del servidor",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet. El archivo .htaccess no está funcionando. Le sugerimos encarecidamente que configure su servidor web de modo que el directorio de datos ya no sea accesible o que mueva el directorio de datos fuera de la raíz de documentos del servidor web.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "La \"{header}\" cabecera HTTP no está configurado para ser igual a \"{expected}\". Esto puede suponer un riesgo para la seguridad o la privacidad, por lo que se recomienda ajustar esta opción.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "La cabecera HTTP \"Strict-Transport-Security\" no está configurada en al menos \"{segundos}\" segundos. Para una mejor seguridad recomendamos que habilite HSTS como se describe en <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Está ingresando a este sitio de internet vía HTTP. Le sugerimos enérgicamente que configure su servidor que utilice HTTPS como se describe en nuestros <a href=\"{docUrl}\">consejos de seguridad</a>.",
    "Shared" : "Compartido",
    "Shared with {recipients}" : "Compartido con {recipients}",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error al dejar de compartir",
    "The public link will expire no later than {days} days after it is created" : "El vínculo público no expirará antes de {days} desde que se creó",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Expiration" : "Expira en:",
    "Expiration date" : "Fecha de caducidad",
    "Expiration date is required" : "Fecha de caducidad requerida",
    "Delete {link}" : "Borrar {link}",
    "Remove link" : "Eliminar link",
    "{fileName} link" : "{fileName} link",
    "Link" : "Enlace",
    "Create public link" : "Crear un link público",
    "Edit" : "Editar",
    "Remove" : "Eliminar",
    "Click to copy to clipboard" : "Clic para copiar al portapapeles",
    "Social share" : "Compartido social",
    "There are currently no link shares, you can create one" : "No existen enlaces comparftidos, deberia crear uno",
    "Anyone with the link has access to the file/folder" : "Quienquiera que posea el vínculo tendrá acceso al archivo/carpeta",
    "Copied!" : "Copiado!",
    "Not supported!" : "Sin asistencia técnica!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "Choose a password for the public link" : "Elija una contraseña para el enlace publico",
    "Password required" : "Se requiere contraseña",
    "Filename" : "Nombre",
    "Password" : "Contraseña",
    "Name" : "Nombre",
    "Allow editing" : "Permitir edición",
    "Show file listing" : "Mostrar listado de archivos",
    "Edit link share: {name}" : "Editar link compartido: {name}",
    "Save" : "Guardar",
    "Create link share: {name}" : "Crear link compartido: {name}",
    "Remove password" : "Eliminar la contraseña",
    "Share to Twitter. Opens in a new window." : "Compartir en Twitter. Se abre en una nueva ventana.",
    "Share to Facebook. Opens in a new window." : "Compartir en Facebook. Se abre en una nueva ventana.",
    "Share to Diaspora. Opens in a new window." : "Compartir en Diaspora. Se abre en una nueva ventana.",
    "Share to Google+. Opens in a new window." : "Compartir en Google+. Se abre en una nueva ventana.",
    "Share via email. Opens your mail client." : "Compartir por correo electrónico. Abre su cliente de correo.",
    "Error while sending notification" : "Error mientras se enviaba la notificación",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send link via email" : "Enviar el link por email",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "group" : "grupo",
    "remote" : "remoto",
    "notify by email" : "notificar por correo electrónico",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "create" : "crear",
    "change" : "cambio",
    "delete" : "eliminar",
    "access control" : "control de acceso",
    "Could not unshare" : "No se puede quitar el comparto",
    "Share details could not be loaded for this item." : "No se han podido cargar los detalles de compartición para este elemento.",
    "No users or groups found for {search}" : "No se han encontrado usuarios ni grupos para {search}",
    "No users found for {search}" : "No se han encontrado usuarios para {search}",
    "An error occurred. Please try again" : "Ha ocurrido un error. Por favor inténtelo de nuevo",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (at {server})" : "{sharee} (en {server})",
    "{sharee} (remote)" : "{sharee} (remoto)",
    "Share" : "Compartir",
    "User and Groups" : "Usuarios y grupos",
    "Public Links" : "Enlaces Publicos",
    "Resharing is not allowed" : "No se permite compartir de nuevo",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Comparta con personas en otros ownClouds utilizando la sintáxis username@example.com/owncloud",
    "Share with users…" : "Compartir con usuarios...",
    "Share with users, groups or remote users…" : "Compartir con usuarios, grupos o usuarios remotos...",
    "Share with users or groups…" : "Compartir con usuarios o grupos...",
    "Share with users or remote users…" : "Compartir con usuarios o usuarios remotos...",
    "Error removing share" : "Error quitando el comparto",
    "Warning" : "Precaución",
    "Non-existing tag #{tag}" : "Categoría #{tag} no existente",
    "restricted" : "Restringido",
    "invisible" : "invisible",
    "({scope})" : "({scope})",
    "Delete" : "Eliminar",
    "Rename" : "Renombrar",
    "Collaborative tags" : "Etiquetas colaborativas",
    "The object type is not specified." : "El tipo de objeto no está especificado.",
    "Enter new" : "Ingresar nueva",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error al cargar plantilla de diálogo: {error}",
    "No tags selected for deletion." : "No hay etiquetas seleccionadas para borrar.",
    "unknown text" : "texto desconocido",
    "Hello world!" : "¡Hola mundo!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el día es {weather}",
    "Hello {name}" : "Hola {name}",
    "new" : "Nuevo",
    "_download %n file_::_download %n files_" : ["descargar %n ficheros","descargar %n archivos"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, salir de esta página podrían interrumpir el proceso en algunos entornos.",
    "Updating to {version}" : "Actualizando a {version}",
    "An error occurred." : "Ocurrió un error.",
    "Please reload the page." : "Recargue/Actualice la página",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización tuvo un problema. Para más información <a href=\"{url}\">consulta nuestro artículo del foro</a> para arreglar este problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La actualización ha fracasado. Por favor, informe de este problema a la <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">Comunidad de ownCloud</a>.",
    "The update was successful. There were warnings." : "La actualización fue exitosa. Había advertencias.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización se ha realizado con éxito. Redireccionando a ownCloud ahora.",
    "Searching other places" : "Buscando en otros lugares",
    "No search results in other folders" : "Ningún resultado de búsqueda en otras carpetas",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de búsqueda en otra carpeta","{count} resultados de búsqueda en otras carpetas"],
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso denegado",
    "File not found" : "Archivo no encontrado",
    "The specified document has not been found on the server." : "El documento indicado no se ha encontrado en el servidor.",
    "You can click here to return to %s." : "Puede hacer clic aquí para volver a %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola:\n\nTan solo queremos informarte que %s compartió %s contigo.\nMíralo aquí: %s\n\n",
    "The share will expire on %s." : "El objeto dejará de ser compartido el %s.",
    "Cheers!" : "¡Saludos!",
    "Internal Server Error" : "Error interno del servidor",
    "The server encountered an internal error and was unable to complete your request." : "El servidor ha encontrado un error y no puede completar la solicitud.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Por favor, contacte con el administrador del servidor si este error reaparece múltiples veces. Incluya asimismo los detalles técnicos que se muestran a continuación.",
    "More details can be found in the server log." : "Pueden verse más detalles en el registro del servidor.",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de la solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Trace" : "Trazas",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Storage & database" : "Almacenamiento y base de datos",
    "Data folder" : "Directorio de datos",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Solo %s está disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Instalar y activar módulos PHP adicionales para elegir otros formatos de base de datos.",
    "For more details check out the documentation." : "Para más detalles revisar la documentación.",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Host de la base de datos",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Por favor especifique el numero del puerto y su host (ej: localhost:5432).",
    "Performance warning" : "Advertencia de rendimiento",
    "SQLite will be used as database." : "Se utilizará SQLite como base de datos.",
    "For larger installations we recommend to choose a different database backend." : "Para grandes instalaciones recomendamos seleccionar una base de datos diferente",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLite esta desaconsejado especialmente cuando se usa el cliente de escritorio para sincronizar los ficheros.",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando...",
    "Need help?" : "¿Necesita ayuda?",
    "See the documentation" : "Vea la documentación",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hola:<br><br>Te comentamos que %s compartió <strong>%s</strong> contigo.<br><a href=\"%s\">¡Échale un vistazo!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere JavaScript para operar correctamente. Por favor, {linkstart}habilite JavaScript{linkend} y recargue la página.",
    "Log out" : "Salir",
    "Search" : "Buscar",
    "Server side authentication failed!" : "La autenticación a fallado en el servidor.",
    "Please contact your administrator." : "Por favor, contacte con el administrador.",
    "An internal error occurred." : "Ha habido un error interno.",
    "Please try again or contact your administrator." : "Por favor reintente nuevamente o contáctese con su administrador.",
    "Username or email" : "Nombre de usuario o email",
    "Log in" : "Iniciar sesión",
    "Wrong password. Reset it?" : "Contraseña incorrecta. ¿Restablecerla?",
    "Wrong password." : "Contraseña incorrecta.",
    "Stay logged in" : "Permanecer autenticado",
    "Alternative Logins" : "Inicios de sesión alternativos",
    "Use the following link to reset your password: {link}" : "Utilice el siguiente enlace para restablecer su contraseña: {link}",
    "Password changed successfully" : "Contraseña cambiada con exito",
    "New password" : "Nueva contraseña",
    "New Password" : "Contraseña nueva",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instalación de ownCloud se encuentra en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
    "Thank you for your patience." : "Gracias por su paciencia.",
    "Two-step verification" : "Verificación en dos pasos",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "La seguridad mejorada se ha habilitado para tu cuenta. Por favor, autenticar utilizando un segundo factor.",
    "Cancel login" : "Cancelar inicio de sesión",
    "Please authenticate using the selected factor." : "Por favor, autenticar utilizando el factor seleccionado.",
    "An error occurred while verifying the token" : "Ocurrió un error mientras se verificaba el \"token\".",
    "You are accessing the server from an untrusted domain." : "Está accediendo al servidor desde un dominio inseguro.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contacte con su administrador. Si usted es el administrador, configure \"trusted_domains\" en config/config.php. En config/config.sample.php se encuentra un ejemplo para la configuración.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependiendo de su configuración, como administrador, debería poder usar el botón de abajo para confiar en este dominio.",
    "Add \"%s\" as trusted domain" : "Añadir \"%s\" como dominio de confianza",
    "App update required" : "Es necesaria una actualización en la aplicación",
    "%s will be updated to version %s" : "%s será actualizada a la versión %s",
    "These apps will be updated:" : "Estas aplicaciones serán actualizadas:",
    "The theme %s has been disabled." : "El tema %s ha sido desactivado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Antes de proceder, asegúrese de que se haya hecho un respaldo de la base de datos, la carpeta de configuración y la carpeta de datos.",
    "Start update" : "Iniciar actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tiempos de espera en grandes instalaciones, en su lugar puede ejecutar el siguiente comando desde el directorio de instalación:",
    "Detailed logs" : "Registros detallados",
    "Update needed" : "Se necesita actualización",
    "Please use the command line updater because you have a big instance." : "Por favor utilice la actualización mediante la linea de comandos porque tiene pendiente una gran actualización.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Para ayuda, mirar  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> la documentación</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Está instancia %s está en modo mantenimiento, por lo que puede llevar un tiempo.",
    "This page will refresh itself when the %s instance is available again." : "La página se refrescará cuando la instalación %s vuelva a estar disponible.",
    "Could not reset password because the token is invalid" : "No se pudo restablecer la contraseña porque el vale de identificación no es válido",
    "Could not reset password because the token expired" : "No se pudo restablecer la contraseña porque vale de identificación ha caducado",
    "Could not reset password because the token does not match" : "No se pudo restablecer la contraseña porque el vale de identificación no coincide",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Choose a password" : "Elige una contraseña",
    "Upload only" : "Sólo descarga",
    "Sending" : "Enviando",
    "Menu" : "Menú",
    "Read only" : "Sólo leer",
    "Read & Write" : "Leer y Escribir",
    "Email notification not sent" : "No se ha enviado la notificación por correo electrónico",
    "You took too long to login, please try again now" : "Ha tardado demasiado en logearse, por favor intentelo de nuevo",
    "Choose an expiration date" : "Elija fecha de expiración",
    "An error occured" : "Ha ocurrido un error",
    "Send copy to self" : "Enviarme una copia a mi mismo",
    "Add personal message" : "Añadir un mensaje personal.",
    "Error adding {addItem}: {addItem} already exists" : "Error añadiendo {addItem}: {addItem} Ya existe.",
    "federated" : "Federado",
    "Recipients can view, download, edit, delete and upload contents." : "Se puede ver, descargar, editar, borrar y subir contenido.",
    "Link name" : "Nombre del enlace",
    "Download / View" : "Descargar / Ver",
    "Download / View / Upload" : "Descargar / Ver / Subir",
    "Owner: {owner}" : "Propietario: {owner}",
    "Email notification was sent!" : "¡Se ha enviado una notificación por correo electrónico!",
    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Por favor, ponte en contacto con el administrador del servidor si este error aparece más veces, e incluye los detalles técnicos en tu informe a continuación.",
    "You are trying to access a private link. Please log in first." : "Estás intentando acceder a un enlace privado. Por favor, inicia sesión primero.",
    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Parece que su instalación tiene demasiados host, archivos o usuarios. Para garantizar una actualización suave, por favor use la actualización por linea de comandos (occ upgrade)",
    "Couldn't send mail to following recipient(s): %s " : "No se puede enviar un correo electrónico a los siguientes receptores: %s ",
    "Receive files from multiple recipients without revealing the contents of the folder." : "Recibir archivos de multiples origenes sin revelar el contenido de la carpeta.",
    "Recipients can view or download contents." : "Se puede ver o descargar el contenido",
    "An error occured while sending email" : "Un error ocurrió mientras se enviaba el correo",
    "{sharee} (federated)" : "{sharee} (federado)",
    "Personal note from the sender: %s." : "Nota personal del origen: %s.",
    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "La actualización autómatica ha sido deshabilitada en config.php. Para actualizar use la linea de comandos (occ upgrade).",
    "Imprint" : "Imprimir",
    "E-Mail sent" : "E-Mail enviado",
    "Privacy Policy" : "Política de privacidad",
    "Sharing is not allowed" : "No se permite compartir",
    "Personal note from the sender: <br> %s." : "Nota personal del remitente: <br> %s."
},
"nplurals=2; plural=(n != 1);");
